==> eisp-mdm-0.0.2-RELEASE.jar: com/biz/eisp/mdm/customer/sql/TmCustomerDao_findTmCustTomerByAllPossible.sql <==
SELECT * FROM TM_CUSTOMER TC WHERE TC.ENABLE_STATUS=0
<#if queryTmCustomerVo.id ?exists&&queryTmCustomerVo.id ?length gt 0>
	AND TC.ID = '${queryTmCustomerVo.id}'
</#if>
<#if queryTmCustomerVo.customerName ?exists&&queryTmCustomerVo.customerName ?length gt 0>
	AND TC.CUSTOMER_NAME LIKE '%${queryTmCustomerVo.customerName}%'
</#if>
<#if queryTmCustomerVo.customerCode ?exists&&queryTmCustomerVo.customerCode ?length gt 0>
	AND TC.CUSTOMER_CODE LIKE '%${queryTmCustomerVo.customerCode}%'
</#if>
<#if queryTmCustomerVo.customerType ?exists&&queryTmCustomerVo.customerType ?length gt 0>
	AND TC.CUSTOMER_TYPE = '${queryTmCustomerVo.customerType}'
</#if>
<#if queryTmCustomerVo.orgId ?exists&&queryTmCustomerVo.orgId ?length gt 0>
	AND TC.ORG_ID = '${queryTmCustomerVo.orgId}'
</#if>
<#if queryTmCustomerVo.cooperative ?exists&&queryTmCustomerVo.cooperative ?length gt 0>
	AND TC.COOPERATIVE = '${queryTmCustomerVo.cooperative}'
</#if>
<#if queryTmCustomerVo.orgName ?exists&&queryTmCustomerVo.orgName ?length gt 0>
	AND TC.ID IN (SELECT TT.ID FROM TM_CUSTOMER TT JOIN TM_ORG TG ON TT.ORG_ID=TG.ID WHERE TG.ORG_NAME LIKE '%${queryTmCustomerVo.orgName}%')
</#if>
<#if queryTmCustomerVo.levelAllOrgId ?exists&&queryTmCustomerVo.levelAllOrgId ?length gt 0>
	AND TC.ORG_ID IN (
		SELECT ID FROM TM_ORG START WITH ID='${queryTmCustomerVo.levelAllOrgId}' CONNECT BY PRIOR ID=PARENT_ID
	)
</#if>

<#if queryTmCustomerVo.levelAllOrgIds ?exists&&queryTmCustomerVo.levelAllOrgIds ?length gt 0>
	AND TC.ORG_ID IN (
		SELECT ID FROM TM_ORG START WITH ID in (${queryTmCustomerVo.levelAllOrgIds}) CONNECT BY PRIOR ID=PARENT_ID
	)
</#if>

<#if queryTmCustomerVo.positionId ?exists&&queryTmCustomerVo.positionId ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_CUST_POS_BG TCP ON TT.ID=TCP.CUSTOMER_ID
		WHERE TCP.POSITION_ID='${queryTmCustomerVo.positionId}'
	)
</#if>
<#if queryTmCustomerVo.positionName ?exists&&queryTmCustomerVo.positionName ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_CUST_POS_BG TCP ON TT.ID=TCP.CUSTOMER_ID
		JOIN TM_POSITION TP ON TP.ID=TCP.POSITION_ID
		WHERE TP.POSITION_NAME LIKE '%${queryTmCustomerVo.positionName}%'
	)
</#if>
<#if queryTmCustomerVo.levelAllPositionId ?exists&&queryTmCustomerVo.levelAllPositionId ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_CUST_POS_BG TCP ON TT.ID=TCP.CUSTOMER_ID
		JOIN TM_POSITION TP ON TP.ID=TCP.POSITION_ID
		START WITH TP.ID='${queryTmCustomerVo.levelAllPositionId}' CONNECT BY PRIOR TP.ID=TP.PARENT_ID
	)
</#if>
<#if queryTmCustomerVo.userId ?exists&&queryTmCustomerVo.userId ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_USER_CUSTOMER TUC ON TUC.CUSTOMER_ID=TT.ID
		JOIN TM_USER TU ON TU.ID=TUC.USER_ID
		WHERE TU.ID='${queryTmCustomerVo.userId}'
	)
</#if>
<#if queryTmCustomerVo.fullName ?exists&&queryTmCustomerVo.fullName ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_USER_CUSTOMER TUC ON TUC.CUSTOMER_ID=TT.ID
		JOIN TM_USER TU ON TU.ID=TUC.USER_ID
		WHERE TU.FULLNAME LIKE '%${queryTmCustomerVo.fullName}%'
	)
</#if>

==> eisp-mdm-1.0.2-RELEASE.jar: com/biz/eisp/mdm/customer/sql/TmCustomerDao_findTmCustTomerByAllPossible.sql <==
SELECT * FROM TM_CUSTOMER TC WHERE TC.ENABLE_STATUS=0
<#if queryTmCustomerVo.id ?exists&&queryTmCustomerVo.id ?length gt 0>
	AND TC.ID = '${queryTmCustomerVo.id}'
</#if>
<#if queryTmCustomerVo.customerName ?exists&&queryTmCustomerVo.customerName ?length gt 0>
	AND TC.CUSTOMER_NAME LIKE '%${queryTmCustomerVo.customerName}%'
</#if>
<#if queryTmCustomerVo.customerCode ?exists&&queryTmCustomerVo.customerCode ?length gt 0>
	AND TC.CUSTOMER_CODE LIKE '%${queryTmCustomerVo.customerCode}%'
</#if>
<#if queryTmCustomerVo.customerType ?exists&&queryTmCustomerVo.customerType ?length gt 0>
	AND TC.CUSTOMER_TYPE = '${queryTmCustomerVo.customerType}'
</#if>
<#if queryTmCustomerVo.orgId ?exists&&queryTmCustomerVo.orgId ?length gt 0>
	AND TC.ORG_ID = '${queryTmCustomerVo.orgId}'
</#if>
<#if queryTmCustomerVo.cooperative ?exists&&queryTmCustomerVo.cooperative ?length gt 0>
	AND TC.COOPERATIVE = '${queryTmCustomerVo.cooperative}'
</#if>
<#if queryTmCustomerVo.terminalId ?exists&&queryTmCustomerVo.terminalId ?length gt 0>
	AND TC.ID IN (SELECT CUSTOMER_ID FROM TM_R_TERM_CUST_POS_BG WHERE TERMINAL_ID='${queryTmCustomerVo.terminalId}')
</#if>
<#if queryTmCustomerVo.orgName ?exists&&queryTmCustomerVo.orgName ?length gt 0>
	AND TC.ID IN (SELECT TT.ID FROM TM_CUSTOMER TT JOIN TM_ORG TG ON TT.ORG_ID=TG.ID WHERE TG.ORG_NAME LIKE '%${queryTmCustomerVo.orgName}%')
</#if>
<#if queryTmCustomerVo.levelAllOrgId ?exists&&queryTmCustomerVo.levelAllOrgId ?length gt 0>
	AND TC.ORG_ID IN (
		SELECT ID FROM TM_ORG START WITH ID='${queryTmCustomerVo.levelAllOrgId}' CONNECT BY PRIOR ID=PARENT_ID
	)
</#if>

<#if queryTmCustomerVo.levelAllOrgIds ?exists&&queryTmCustomerVo.levelAllOrgIds ?length gt 0>
	AND TC.ORG_ID IN (
		SELECT ID FROM TM_ORG START WITH ID in (${queryTmCustomerVo.levelAllOrgIds}) CONNECT BY PRIOR ID=PARENT_ID
	)
</#if>

<#if queryTmCustomerVo.positionId ?exists&&queryTmCustomerVo.positionId ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_CUST_POS_BG TCP ON TT.ID=TCP.CUSTOMER_ID
		WHERE TCP.POSITION_ID='${queryTmCustomerVo.positionId}'
	)
</#if>
<#if queryTmCustomerVo.positionName ?exists&&queryTmCustomerVo.positionName ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_CUST_POS_BG TCP ON TT.ID=TCP.CUSTOMER_ID
		JOIN TM_POSITION TP ON TP.ID=TCP.POSITION_ID
		WHERE TP.POSITION_NAME LIKE '%${queryTmCustomerVo.positionName}%'
	)
</#if>
<#if queryTmCustomerVo.levelAllPositionId ?exists&&queryTmCustomerVo.levelAllPositionId ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_CUST_POS_BG TCP ON TT.ID=TCP.CUSTOMER_ID
		JOIN TM_POSITION TP ON TP.ID=TCP.POSITION_ID
		START WITH TP.ID='${queryTmCustomerVo.levelAllPositionId}' CONNECT BY PRIOR TP.ID=TP.PARENT_ID
	)
</#if>
<#if queryTmCustomerVo.userId ?exists&&queryTmCustomerVo.userId ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_USER_CUSTOMER TUC ON TUC.CUSTOMER_ID=TT.ID
		JOIN TM_USER TU ON TU.ID=TUC.USER_ID
		WHERE TU.ID='${queryTmCustomerVo.userId}'
	)
</#if>
<#if queryTmCustomerVo.fullName ?exists&&queryTmCustomerVo.fullName ?length gt 0>
	AND TC.ID IN(
		SELECT TT.ID FROM TM_CUSTOMER TT
		JOIN TM_R_USER_CUSTOMER TUC ON TUC.CUSTOMER_ID=TT.ID
		JOIN TM_USER TU ON TU.ID=TUC.USER_ID
		WHERE TU.FULLNAME LIKE '%${queryTmCustomerVo.fullName}%'
	)
</#if>
